ExtendedSignature

Struct ExtendedSignature 

pub struct ExtendedSignature<PublicKey = PublicKey, Signature = Signature> { /* private fields */ }
An extended signature carries the key that may be used to verify the signature along with the signature itself.

Implementations

Source

impl ExtendedSignature

pub fn try_sign(signer: &impl Signer, payload: &[u8]) -> Result<Self, Error>

Source

impl<VerifyingKey, Signature> ExtendedSignature<VerifyingKey, Signature>
where VerifyingKey: Verifier<Signature>,

pub fn verify(&self, msg: &[u8]) -> Result<(), Error>

Verify the signature for a given payload.

Source

impl<VerifyingKey, Signature> ExtendedSignature<VerifyingKey, Signature>

pub fn new(key: VerifyingKey, sig: Signature) -> Self

Create a new extended signature.

pub fn key(&self) -> &VerifyingKey

pub fn sig(&self) -> &Signature

pub fn into_pair(self) -> (VerifyingKey, Signature)