pub struct PublicKey(/* private fields */);Expand description
Bytes that are intended/thought to correspond to a point on the Edwards25519 curve (but not on its twist).
This is more compact than VerifyingKey in memory, and easier to handle,
but it is not guaranteed to be a valid point on the curve, so cannot be used
for actual cryptographic operations such as signature verification or
Diffie-Hellman key exchange.
Implementations
Sourceimpl PublicKey
impl PublicKey
pub const fn from_bytes(bytes: PublicKeyBytes) -> Self
pub fn into_inner(self) -> PublicKeyBytes